#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

# pyqt5
from PyQt5.QtWidgets import QWizard, QApplication
from PyQt5.QtCore import QSize
from PyQt5.QtGui import QPixmap

# import pages
from ui.pages import page1, page2, page3, page4, page5, page0

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class MagicWizard(QWizard):

    #
    def __init__(self, mainDir, os_valid, logPath, filesPaths, parent=None):
        super(MagicWizard, self).__init__(parent)

        # headers
        self.setObjectName("mainWindow")
        self.setWindowTitle("Correction des caractères OneDrive")
    
        # geometry
        self.resize(640,480)
        self.setMinimumSize(QSize(640,480))
        # self.setMaximumSize(QSize(640,480))
        
        # set banner image
        self.setPixmap(self.BackgroundPixmap, QPixmap(mainDir + "/resources/images/s2o-bn2.png"))

        # options to hide buttons
        self.setOptions(
            self.NoBackButtonOnStartPage
            | self.NoBackButtonOnLastPage
            | self.NoCancelButton
        )

        # P1 - intro
        self.p1 = page1.Page1(os_valid)
        self.p1Id = self.addPage(self.p1)

        # P2 - folder selection
        self.p2 = page2.Page2()
        self.p2Id = self.addPage(self.p2)

        # P3 - worker: index+regex
        self.p3 = page3.Page3(filesPaths)
        self.p3Id = self.addPage(self.p3)
        # retreive oneDrivePath from page2
        self.p2.sig_string.connect(self.p3.updatePath)
        # jump to next page
        self.p3.sig_next.connect(self.next)

        # P4 - list of results
        self.p4 = page4.Page4(filesPaths)
        self.p4Id = self.addPage(self.p4)
        # retreive oneDrivePath from page2
        self.p2.sig_string.connect(self.p4.updatePath)
        # set next page
        self.p4.sig_next.connect(self.skipRenaming)

        # P5 - worker: renaming
        self.p5 = page5.Page5(filesPaths)
        self.p5Id = self.addPage(self.p5)
        # set next page
        self.p5.sig_next.connect(self.next)

        # P0 - summary
        self.p0 = page0.Page0(filesPaths)
        self.p0Id = self.addPage(self.p0)
        # retreive oneDrivePath from page2
        self.p2.sig_string.connect(self.p0.updatePath)

    #
    def skipRenaming(self):
        #
        self.p4.nextId = lambda: self.p0Id


#-------------------------------------------------
# run GUI
def makeGui(mainDir, os_valid, logPath, filesPaths):
    
    import sys
    app = QApplication(sys.argv)
    wizard = MagicWizard(mainDir, os_valid, logPath, filesPaths)
    wizard.show()
    sys.exit(app.exec_())

