#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QWizardPage

from common.logger import logMsg
from common.scrollLabel import ScrollLabel
import csv

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Page0(QWizardPage):

    def __init__(self, filesPaths, parent=None):
        super(Page0, self).__init__(parent)

        # attributes
        self.renameConflictsFilePath = filesPaths[3]

        #headers
        self.setTitle("Terminé")
        
        #subtitle
        self.setSubTitle("Merci d'avoir utilisé cette application.\n\n"
                         "Vos remarques quant à son utilisation sont les "
                         "bienvenues à helpdesk@unil.ch, 021 692 22 11.")

        # label
        self.label = QtWidgets.QLabel()
        self.label.setText("Les modifications suivantes n'ont pas été apportées pour "
                           "éviter des conflits de nom déjà existant.\n"
                           "Nous vous laissons les renomer et choisir un nom approprié:")
        self.label.setVisible(False)
        self.label.setWordWrap(True) 
        
        # scroll label
        self.scroll1 = ScrollLabel()
        self.scroll1.setVisible(False)

        #layout
        layout = QtWidgets.QVBoxLayout()
        layout.addWidget(self.label)
        layout.addWidget(self.scroll1)
        self.setLayout(layout)

    # function just to receive value from page2 signal
    def updatePath(self, sig):
        self.oneDrivePath = sig

    #-------------------------------------------------
    # initializePage
    #-------------------------------------------------

    # on page opening
    def initializePage(self):
        
        # log
        logMsg("PAGE", "0")

        # read renameFile
        self.renameConflictsFile = open(self.renameConflictsFilePath, "r")

        # check if not empty
        if self.renameConflictsFile.read(1):
            
            # log
            logMsg("INFO", "renameUniqueFile is not empty.")

            # make label and scroll area visible
            self.label.setVisible(True)
            self.scroll1.setVisible(True)

            # restart pointer at line 0 for the loop
            self.renameConflictsFile.seek(0)
            
            # realtive file content in the scrollLabel
            dataReader = csv.reader(self.renameConflictsFile, delimiter="\t")
            content = ""

            # clean csv content
            for column in dataReader:
                
                # absolute to relative path
                leftColumn = column[0].replace(self.oneDrivePath, '. ')
                rightColumn = column[1].replace(self.oneDrivePath, '. ')
                # assemble
                line = leftColumn + "\n" + rightColumn + "\n----\n"
                content = content + line
            # assign it to scroll label
            self.scroll1.setText(content)


        # if empty
        else:    
            # log
            logMsg("INFO", "renameUniqueFile is empty.")

        # close renameFile
        self.renameConflictsFile.close()
