#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5.QtCore import QObject, pyqtSignal
import os
from common.logger import logMsg

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Worker1(QObject):
    
    # signals
    sig_string = pyqtSignal(str)
    sig_progress = pyqtSignal(int)
    sig_maxProgress = pyqtSignal(int)
    sig_workerEnd = pyqtSignal()

    #
    def __init__(self, folder_path, indexFilePath, parent=None):
        QObject.__init__(self, parent)
        
        # attributes
        self.folder_path = folder_path
        self.indexFilePath = indexFilePath

    # Indexing
    def makeIndex(self):

        # set signals
        self.sig_progress.emit(0)
        self.sig_maxProgress.emit(0)
        self.sig_string.emit("Indexation des fichiers...")
        
        # log
        logMsg("INFO", "makeIndex START")

        # open index file as write
        self.indexFile = open(self.indexFilePath, "w")

        # define macos packages type
        self.macOSpackages = (".app", ".bundle", ".framework", ".plugin", ".kext")
        
        # list for index
        self.indexList = []

        # for loop to index all elements in folder_path
        for root, dirs, files in os.walk(self.folder_path, topdown=True):
            
            # for each dir
            for name in dirs[:]:
                # exception for macOS packages
                if name.endswith(self.macOSpackages):
                    # print it in index
                    self.indexList.append(os.path.join(root, name))
                    # but remove it from recursive loop (do not loop inside it)
                    dirs.remove(name)
                else:
                    self.indexList.append(os.path.join(root, name))

            # for each file
            for name in files:
                self.indexList.append(os.path.join(root, name))

        # reverse the list (so we don't rename a folder before it's content)
        for i in reversed(self.indexList):
            self.indexFile.write(i + '\n')

        #close index
        self.indexFile.close()

        #log
        logMsg("INFO", "makeIndex END")

        #end sig
        self.sig_progress.emit(1)
        self.sig_maxProgress.emit(1)
        self.sig_workerEnd.emit()
 